require 'synchronize/tasks'
require 'synchronize/db'
require 'synchronize/utils'
require 'synchronize/assets'

default_command :all

command :all do |c|
  c.syntax = "#{program(:name)}"
  c.description = "Synchronizes assets and database."
  c.option '-K', '--knife PATH', String, 'Path to knife config file'
  c.option '-k', '--aws_accesskey KEY', String, 'aws secret access key.'
  c.option '-I', '--aws_accessid KEY', String, 'aws access key id.'
  c.option '-b', '--aws_bucket BUCKET', String, 'aws bucket name.'
  c.option '-e', '--rails_env ENVIRONMENT', String, 'rails environment'
  c.option '-u', '--mysql_user USERNAME (Defaults to root)', String, 'mysql user'
  c.option '-p', '--mysql_pass PASSWORD (Defaults to empty)', String, 'mysql password'
  c.option '-h', '--mysql_host HOSTNAME (Defaults to 127.0.0.1)', String, 'mysql hostname'
  c.option '-d', '--database NAME', String, 'database'
  c.action do |args, options|
    @options = options
    check_environment
    get_rails_env
    get_mysql_credentials
    get_aws_credentials
    get_app_name
    get_production_db_name
    get_latest_s3_dump
    unzip_database
    load_database
    rm_dump
    duplicity_restore
  end
end

command :assets do |c|
  c.syntax = "#{program(:name)} assets"
  c.description = "Synchronizes the assets to the system directory"
  c.option '-K', '--knife PATH', String, 'Path to knife config file'
  c.option '-k', '--aws_accesskey KEY', String, 'aws secret access key.'
  c.option '-I', '--aws_accessid KEY', String, 'aws access key id.'
  c.option '-b', '--aws_bucket BUCKET', String, 'aws bucket name.'
  c.action do |args, options|
    @options = options
    check_environment
    get_aws_credentials
    get_app_name
    duplicity_restore
  end
end

command :db do |c|
  c.syntax = "#{program(:name)} db"
  c.description = "Synchronizes a database with the latest s3 dbdump."
  c.option '-K', '--knife PATH', String, 'Path to knife config file'
  c.option '-k', '--aws_accesskey KEY', String, 'aws secret access key.'
  c.option '-I', '--aws_accessid KEY', String, 'aws access key id.'
  c.option '-b', '--aws_bucket BUCKET', String, 'aws bucket name.'
  c.option '-e', '--rails_env ENVIRONMENT', String, 'rails environment'
  c.option '-u', '--mysql_user USERNAME (Defaults to root)', String, 'mysql user'
  c.option '-p', '--mysql_pass PASSWORD (Defaults to empty)', String, 'mysql password'
  c.option '-h', '--mysql_host HOSTNAME (Defaults to 127.0.0.1)', String, 'mysql hostname'
  c.option '-d', '--database NAME', String, 'database'
  c.action do |args, options|
    @options = options
    check_environment
    get_rails_env
    get_mysql_credentials
    get_aws_credentials
    get_app_name
    get_production_db_name
    get_latest_s3_dump
    unzip_database
    load_database
    rm_dump
  end
end

command :db2disk do |c|
  c.syntax = "#{program(:name)} db2disk"
  c.description = "Downloads the latest backup from s3 to local disk."
  c.action do |args, options|
    check_environment
    get_aws_credentials
    get_app_name
    get_production_db_name
    get_latest_s3_dump
    unzip_database
  end
end

command :check do |c|
  c.syntax = "#{program(:name)} check"
  c.description = "Perform a health check of system dependencies and environment variables required in order to run synchronize"
  c.action do |args, options|
    check_environment
  end
end

command :dependencies do |c|
  c.syntax = "#{program(:name)} dependencies"
  c.description = "Installs the command line tools required for synchronize to work. Requires brew."
  c.action do |args, options|
    install_dependencies
  end
end



