require 'synchronize/tasks'

def get_latest_s3_dump
  puts "  - Downloading #{@app_name} S3 dump."
  connection = Fog::Storage.new(
                                :provider                 => 'AWS',
                                :aws_secret_access_key    => @aws_secret_access_key,
                                :aws_access_key_id        => @aws_access_key_id
                                )

  directory = connection.directories.get(@bucket)
  s3_file_url = "projects/#{@app_name}/dbdumps/#{@production_db}/latest.gz"
  s3_file = directory.files.get(s3_file_url)

  File.open("#{RAILS_ROOT}/#{@production_db}.gz", "w+") do |local_file|
    local_file.write(s3_file.body)
  end
end

def get_mysql_credentials
  if @mysql_option
    @db_user = @options.mysql_user || 'root'
    @db_pass = @options.mysql_pass
    @db_host = @options.mysql_host || '127.0.0.1'
    @db_name = @options.database
  else
    credentials = Utils.load_yaml_file("#{RAILS_ROOT}/config/database.yml")
    @db_user = credentials[@rails_env]['username'] || 'root'
    @db_pass = credentials[@rails_env]['password']
    @db_host = credentials[@rails_env]['host'] || '127.0.0.1'
    @db_name = credentials[@rails_env]['database']
  end
end

def unzip_database
  puts
  puts "  - Unzipping #{@app_name} dump."
  `gunzip -f #{RAILS_ROOT}/#{@production_db}.gz`
  puts "  - #{@app_name} dump sucessfully unzipped."
end

def load_database
  puts "  - Loading #{@app_name} dump into the database."

  command_pre = "mysql -u #{@db_user} -h #{@db_host} "
  command_in = @db_pass ? "-p#{@db_pass} " : String.new

  command_post = "-e \"DROP DATABASE IF EXISTS #{@db_name}; CREATE DATABASE #{@db_name}\""
  system(command_pre + command_in + command_post)

  command_post = "#{@db_name} < #{RAILS_ROOT}/#{@production_db}"
  system(command_pre + command_in + command_post)

  puts $? != 0 ? "  - There was a problem loading database #{@app_name}." : "  - Database #{@app_name} sucessfully loaded."
end

def get_production_db_name
  @production_db = "jorgesancha_#{@app_name}_production"
end

def rm_dump
  `rm -f #{RAILS_ROOT}/#{@production_db}`
end

