# -*- coding: utf-8 -*-
def get_app_name
  @app_name = @rails_env == "development" ? RAILS_ROOT.split('/').last : RAILS_ROOT.split('/')[2]
end

def get_rails_env
 @rails_env = @options.rails_env ? @options.rails_env : ENV['RAILS_ENV']
end

def get_knife_config
  @knife_config =  @options.knife ? @options.knife : ENV['KNIFE_CONFIG']
end

def get_databag(databag, key)
  aws_yml = `unset BUNDLE_GEMFILE; cd /; knife data bag show #{databag} #{key} -F yml -c #{@knife_config}`
  YAML.load(aws_yml)
end

def get_aws_credentials
  if @knife_option
    puts "  - Obtaining AWS credentials from knife."

    aws_data = get_databag('aws','keys')
    @aws_access_key_id = aws_data['aws_access_key_id']
    @aws_secret_access_key = aws_data['aws_secret_access_key']

    aws_data = get_databag('aws','buckets')
    @bucket = aws_data['s3_backup_bucket']

    ENV['AWS_ACCESS_KEY_ID'] = @aws_access_key_id
    ENV['AWS_SECRET_ACCESS_KEY'] = @aws_secret_access_key
  elsif @aws_option
    @bucket = @options.aws_bucket
    @aws_access_key_id = @options.aws_accessid
    @aws_secret_access_key = @options.aws_accesskey
    ENV['AWS_ACCESS_KEY_ID'] = @aws_access_key_id
    ENV['AWS_SECRET_ACCESS_KEY'] = @aws_secret_access_key
  else
    @bucket = ENV['AWS_BUCKET']
    @aws_access_key_id = ENV['AWS_ACCESS_KEY_ID']
    @aws_secret_access_key = ENV['AWS_SECRET_ACCESS_KEY']
  end
end

# Installs the command line tools required for synchronize.
def install_dependencies
  puts "  - Installing dependencies"
  `brew install python`
  `/usr/local/share/python/easy_install pip`
  `/usr/local/share/python/pip install boto`
  `brew install duplicity`
  puts "  - Synchronize dependencies installed"
end

def check_duplicity
  unless `duplicity -V`
    raise "  - duplicity not installed or not in PATH. You can install it manually or run synchronize dependencies to install through brew"
  else
    puts "  - Found duplicity command."
  end
end

def check_knife_env
  if ! ENV['KNIFE_CONFIG']
    @knife_option = false
    puts "  - KNIFE_CONFIG variable or --knife parameter has not been set, falling back to AWS command line options or environment variables."
  elsif ENV['KNIFE_CONFIG'] && ! File.exists?(ENV['KNIFE_CONFIG'])
    raise "  - KNIFE_CONFIG env variable exists but is not pointing to a proper knife config file, please point it to your knife config file."
    else
    puts "  - knife properly configured."
    @knife_option = true
  end
end

def check_knife_option
  @knife_option = true
  if ! @options.knife
    @knife_option = false
  elsif @options.knife  && ! File.exists?(@options.knife)
    raise "  - --knife is not pointing to a proper knife config file, please point it to your knife config file."
    else
    puts "  - knife properly configured."
    @knife_option = true
  end
end

def check_aws_env
  unless ENV['AWS_ACCESS_KEY_ID']
    raise "  - Environment variable AWS_ACCESS_KEY_ID not set."
  end

  unless ENV['AWS_SECRET_ACCESS_KEY']
    raise "  - Environment variable AWS_SECRET_ACCESS_KEY not set."
  end

  unless ENV['AWS_BUCKET']
    raise "  - Enviroment variable AWS_BUCKET not set."
  end

  puts " - AWS env variables present."
end

def check_aws_option
  @aws_option = true if (@options.aws_accesskey && @options.aws_accessid && @options.aws_bucket)
end

def check_aws_knife
  aws_data = get_databag('aws','buckets')
  unless aws_data['s3_backup_bucket']
    raise "  - Could not get s3_backup_bucket parameter from chef databag aws"
  end

  aws_data = get_databag('aws','keys')
  unless aws_data['aws_access_key_id']
    raise "  - Could not get aws_access_key_id parameter from chef databag aws"
  end

  unless aws_data['aws_secret_access_key']
    raise "  - Could not get aws_secret_access_key  parameter from chef databag aws"
  end
end

def check_rails_option
  @rails_option = true if @options.rails_env
end

def check_rails_env
  unless ENV['RAILS_ENV']
    raise "  - Neither environment variable RAILS_ENV nor --rails_env parameter has been set."
  end
  puts "  - RAILS_ENV variable present."
end

def check_database_yml
  unless File.exists?("#{RAILS_ROOT}/config/database.yml")
    raise "database.yml not found, are you running synchronize on your RAILS_ROOT directory?"
  end
  puts  "  - Found database.yml config file"
end

def check_mysql_option
  @mysql_option = true if @options.database
end

# "Tests the existence of the environment variables required for backups tasks"
def check_environment
  puts "  - Checking environment."
  check_duplicity

  check_knife_option
  check_knife_env unless @knife_option
  check_aws_option unless @knife_option

  if (@knife_option && ! @aws_option)
    get_knife_config
    check_aws_knife
  end

  check_aws_env if (! @knife_option && ! @aws_option)

  check_rails_option
  check_rails_env  unless @rails_option

  check_mysql_option
  check_database_yml unless @mysql_option

  puts "  - Environment check successful, you should be able to run synchronize without trouble."
end


